# Generated by roxygen2: do not edit by hand

S3method(predict,soilKey_pls_model)
S3method(print,soilKey_pls_model)
S3method(print,soilkey_uncertainty)
export("%||%")
export(B_espodico)
export(B_incipiente)
export(B_latossolico)
export(B_nitico)
export(B_planico)
export(B_textural)
export(ClassificationResult)
export(DiagnosticResult)
export(FamilyAttribute)
export(GSM_DEPTHS)
export(MockVLMProvider)
export(PedonRecord)
export(abrupt_textural_difference)
export(acrisol)
export(aeolic_material)
export(albeluvic_glossae)
export(albic)
export(alisol)
export(andic_properties)
export(andosol)
export(annotate_wrb_from_usda)
export(anthraquic)
export(anthric_horizons)
export(apply_soilgrids_depth_prior)
export(arenic_texture)
export(argic)
export(argic_aqp)
export(argic_with_strong_clay_films)
export(argillic_clay_films_test)
export(artefacts)
export(as_aqp)
export(attach_lucas_spectra)
export(audit_argic_strong_films)
export(auto_set_proj_env)
export(available_esdb_attributes)
export(batch_robustness)
export(benchmark_afsp)
export(benchmark_bdsolos)
export(benchmark_lucas_2018)
export(benchmark_performance)
export(benchmark_redape)
export(benchmark_run_classification)
export(benchmark_spectral_fill)
export(benchmark_unified)
export(benchmark_wrb_vs_usda)
export(build_taxon_profiles)
export(calcaric_material)
export(calcic)
export(cambic)
export(cambic_aqp)
export(canonical_reference)
export(canonicalise_kst13ed_gg)
export(cerosidade)
export(chernic)
export(chernozem)
export(chernozem_strict)
export(claric_material)
export(classification_robustness)
export(classify_all)
export(classify_by_spectral_neighbours)
export(classify_from_documents)
export(classify_from_photos)
export(classify_sibcs)
export(classify_sibcs_familia)
export(classify_usda)
export(classify_usda_family)
export(classify_via_smartsolos_api)
export(classify_with_engine_heuristic)
export(classify_with_uncertainty)
export(classify_wrb2022)
export(clear_kst13_cache)
export(clear_ossl_cache)
export(combine_priors)
export(compare_engines)
export(compare_smartsolos)
export(compute_ki)
export(compute_kr)
export(compute_per_attribute_evidence_grade)
export(continuous_rock)
export(coverage_report)
export(cryic_conditions)
export(distrofico)
export(dolomitic_material)
export(download_bdsolos)
export(download_extdata_cache)
export(download_ossl_subset)
export(download_ossl_subset_with_labels)
export(download_redape_dataset)
export(duric_horizon)
export(duripa)
export(ensure_horizon_schema)
export(eutrofico)
export(evaluate_rsg_tests)
export(extract_horizons_from_pdf)
export(extract_munsell_from_photo)
export(extract_site_from_fieldsheet)
export(familia_mineralogia_argila_geral)
export(febr_index_munsell)
export(ferralic)
export(ferralsol)
export(ferric)
export(fibrico)
export(fill_from_spectra)
export(fill_munsell_from_spectra)
export(fluvic_material)
export(format_wrb_name)
export(fragic)
export(fragipa)
export(from_aqp)
export(gapfill_by_predicted_taxon)
export(gapfill_derive_horizon)
export(gapfill_within_pedon)
export(get_perturbation_scale)
export(gleyic_properties)
export(gleysol)
export(gypsic)
export(gypsiric_material)
export(harmonize_to_gsm)
export(hemico)
export(histic_horizon)
export(horizon_column_spec)
export(hortic)
export(hydragric)
export(hypersulfidic_material)
export(hyposulfidic_material)
export(inspect_bdsolos_csv)
export(irragric)
export(kastanozem)
export(kastanozem_strict)
export(kst13_canonical)
export(kst13_codes)
export(kst13_criteria)
export(leptic_features)
export(limnic_material)
export(limonic)
export(lithic_discontinuity)
export(lixisol)
export(load_afsp_pedons)
export(load_afsp_sample)
export(load_bdsolos_csv)
export(load_embrapa_pedons)
export(load_febr_pedons)
export(load_kssl_nasis_sample)
export(load_kssl_pedons)
export(load_kssl_pedons_gpkg)
export(load_kssl_pedons_with_nasis)
export(load_kssl_sample)
export(load_lucas_pedons)
export(load_lucas_soil_2018)
export(load_ossl_models)
export(load_redape_pedons)
export(load_rules)
export(load_wosis_sample)
export(load_wosis_stratified_sample)
export(lookup_esdb)
export(lookup_mapbiomas_solos)
export(lookup_soilgrids)
export(luvisol)
export(make_acrisol_canonical)
export(make_alisol_canonical)
export(make_andosol_canonical)
export(make_anthrosol_canonical)
export(make_arenosol_canonical)
export(make_argissolo_canonical)
export(make_calcisol_canonical)
export(make_cambisol_canonical)
export(make_cambissolo_canonical)
export(make_chernossolo_canonical)
export(make_chernozem_canonical)
export(make_cryosol_canonical)
export(make_durisol_canonical)
export(make_empty_horizons)
export(make_espodossolo_canonical)
export(make_ferralsol_canonical)
export(make_fluvisol_canonical)
export(make_gleissolo_canonical)
export(make_gleysol_canonical)
export(make_gypsisol_canonical)
export(make_histosol_canonical)
export(make_kastanozem_canonical)
export(make_latossolo_canonical)
export(make_leptosol_canonical)
export(make_lixisol_canonical)
export(make_luvisol_canonical)
export(make_luvissolo_canonical)
export(make_neossolo_canonical)
export(make_nitisol_canonical)
export(make_nitossolo_canonical)
export(make_organossolo_canonical)
export(make_phaeozem_canonical)
export(make_planosol_canonical)
export(make_planossolo_canonical)
export(make_plinthosol_canonical)
export(make_plintossolo_canonical)
export(make_podzol_canonical)
export(make_retisol_canonical)
export(make_solonchak_canonical)
export(make_solonetz_canonical)
export(make_stagnosol_canonical)
export(make_synthetic_pedon_with_spectra)
export(make_technosol_canonical)
export(make_umbrisol_canonical)
export(make_vertisol_canonical)
export(make_vertissolo_canonical)
export(mineral_material)
export(mollic)
export(mudanca_textural_abrupta)
export(mulmic_material)
export(natric_horizon)
export(nitic_horizon)
export(normalise_febr_sibcs)
export(normalise_febr_usda)
export(normalise_febr_wrb)
export(normalise_kssl_subgroup)
export(ollama_is_running)
export(organic_material)
export(organotechnic_material)
export(ornithogenic_material)
export(ossl_library_template)
export(oxic_usda)
export(panpaic)
export(pedon_json_schema)
export(pedon_to_spc)
export(pedons_from_spectral_table)
export(petrocalcic)
export(petroduric)
export(petrogypsic)
export(petroplinthic)
export(phaeozem)
export(pi_to_confidence)
export(pick_engine)
export(pick_engine_batch)
export(pisoplinthic)
export(plaggic)
export(planic_features)
export(planosol)
export(plinthic)
export(posterior_classify)
export(predict_from_spectra)
export(predict_lab_from_spectra)
export(predict_munsell_from_spectra)
export(predict_ossl_mbl)
export(predict_ossl_plsr_local)
export(predict_ossl_pretrained)
export(predict_xyz_from_spectra)
export(preprocess_spectra)
export(pretic)
export(prior_consistency_check)
export(protocalcic_properties)
export(protogypsic_properties)
export(protovertic)
export(read_febr_pedons)
export(read_spectral_library)
export(reducing_conditions)
export(report)
export(report_html)
export(report_pdf)
export(report_to_qgis)
export(resolve_wrb_qualifiers)
export(retic_properties)
export(run_all_benchmarks)
export(run_classify_app)
export(run_demo)
export(run_sibcs_grande_grupo)
export(run_sibcs_key)
export(run_sibcs_subgrupo)
export(run_sibcs_subordem)
export(run_taxa_list)
export(run_taxonomic_key)
export(run_usda_great_group)
export(run_usda_key)
export(run_usda_subgroup)
export(run_usda_suborder)
export(run_wrb_key)
export(salic)
export(saprico)
export(save_ossl_models)
export(shrink_swell_cracks)
export(sideralic_properties)
export(soil_classes_at_location)
export(soil_organic_carbon)
export(soilgrids_usda_lut)
export(soilgrids_wrb_lut)
export(solimovic_material)
export(sombric)
export(spatial_prior)
export(spatial_prior_embrapa)
export(spatial_prior_soilgrids)
export(spodic)
export(st_features_canonical)
export(stagnic_properties)
export(subgrupo_planossolo_espessos)
export(subgrupo_planossolo_mesicos)
export(subgrupo_plintossolo_endico_concrecionario)
export(subgrupo_plintossolo_endico_litoplintico)
export(subgrupo_plintossolo_espessos)
export(takyric_properties)
export(technic_features)
export(technic_hard_material)
export(tephric_material)
export(terric)
export(texture_class_from_pct)
export(thionic)
export(train_pls_from_ossl)
export(tsitelic)
export(umbric_horizon)
export(usda_to_wrb_rsg)
export(validate_horizon_geometry)
export(validate_pedon_json)
export(vertic_horizon)
export(vertic_properties)
export(vertisol)
export(vitric_properties)
export(vlm_pick_provider)
export(vlm_provider)
export(wrb06_code_to_rsg)
export(wrb2022_canonical)
export(yermic_properties)
importFrom(R6,R6Class)
importFrom(stats,aggregate)
importFrom(stats,predict)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(stats,weighted.mean)
importFrom(utils,tail)
