# Coverage report -- usda suborder

Measured by NAME against the canonical reference set. 68 of 68 canonical suborders are registered (**100.0%**); 0 missing.

## By group

| group | canonical | covered | missing | pct |
|---|---:|---:|---:|---:|
| Alfisols | 5 | 5 | 0 | 100.0% |
| Andisols | 8 | 8 | 0 | 100.0% |
| Aridisols | 7 | 7 | 0 | 100.0% |
| Entisols | 5 | 5 | 0 | 100.0% |
| Gelisols | 3 | 3 | 0 | 100.0% |
| Histosols | 5 | 5 | 0 | 100.0% |
| Inceptisols | 6 | 6 | 0 | 100.0% |
| Mollisols | 8 | 8 | 0 | 100.0% |
| Oxisols | 5 | 5 | 0 | 100.0% |
| Spodosols | 5 | 5 | 0 | 100.0% |
| Ultisols | 5 | 5 | 0 | 100.0% |
| Vertisols | 6 | 6 | 0 | 100.0% |

## Missing (0)

_none_
