# Coverage report -- sibcs all

1187 classes registered. No external canonical SiBCS 5 class list; registered counts only.

## By group

| group | registered |
|---|---:|
| order | 13 |
| suborder | 44 |
| great_group | 192 |
| subgroup | 938 |
