# Coverage report -- wrb2022 qualifier

Measured by NAME against the canonical reference set. 226 of 234 canonical qualifiers are registered (**96.6%**); 8 missing.

## By group

| group | canonical | covered | missing | pct |
|---|---:|---:|---:|---:|
| principal | 131 | 126 | 5 | 96.2% |
| supplementary | 103 | 100 | 3 | 97.1% |

## Exist but inert (stubs) (3)

- Fibric
- Hemic
- Sapric

## Missing (8)

- Claric
- etrosalic
- Fibric
- Hemic
- Novic
- Panpaic
- Sapric
- Sideralic
