% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-horizons-sibcs.R
\name{horizonte_A_moderado}
\alias{horizonte_A_moderado}
\title{Horizonte A moderado (SiBCS Cap 2, p 53-54): catch-all.
Returns TRUE quando o solo tem horizonte superficial mas nao se
enquadra nas demais classes diagnosticas superficiais.}
\usage{
horizonte_A_moderado(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Horizonte A moderado (SiBCS Cap 2, p 53-54): catch-all.
Returns TRUE quando o solo tem horizonte superficial mas nao se
enquadra nas demais classes diagnosticas superficiais.
}
