% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-horizons-sibcs.R
\name{horizonte_litoplintico}
\alias{horizonte_litoplintico}
\title{Horizonte litoplintico (SiBCS Cap 2, p 69; v0.7)}
\usage{
horizonte_litoplintico(pedon, min_thickness = 10)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_thickness}{Numeric threshold or option (see Details).}
}
\description{
Petroplintita continua (ironstone). Reuso de
\code{\link{petroplinthic}} (WRB), espessura \\>= 10 cm.
}
