% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-spodosols-usda.R
\name{placic_horizon_usda}
\alias{placic_horizon_usda}
\title{Placic horizon (USDA, KST 13ed Ch 3, pp 47-48)}
\usage{
placic_horizon_usda(pedon, max_top_cm = 100)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{max_top_cm}{Default 100.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Pass when a thin (1-25 mm) Fe/Mn-cemented horizon is present.
Detected via designation containing 'm' (cemented) AND
\code{cementation_class} in \{strongly, indurated\} AND thickness
between 1 mm and 25 mm.
}
