% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{test_artefacts_concentration}
\alias{test_artefacts_concentration}
\title{Test that artefacts_pct >= threshold within the upper max_top_cm}
\usage{
test_artefacts_concentration(
  h,
  min_pct = 20,
  max_top_cm = 100,
  candidate_layers = NULL
)
}
\arguments{
\item{h}{Numeric threshold or option (see Details).}

\item{min_pct}{Numeric threshold or option (see Details).}

\item{max_top_cm}{Numeric threshold or option (see Details).}

\item{candidate_layers}{Numeric threshold or option (see Details).}
}
\description{
Default 20\% by volume (Technosols criterion, WRB 2022).
}
