% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/canonical-kst13.R
\name{.kst13_load_cached}
\alias{.kst13_load_cached}
\title{Read + cache a KST13 JSON file}
\usage{
.kst13_load_cached(filename)
}
\description{
Read + cache a KST13 JSON file
}
\keyword{internal}
