% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-horizons-sibcs.R
\name{B_planico}
\alias{B_planico}
\title{Horizonte B planico (SiBCS Cap 2, p 65-66; v0.7)}
\usage{
B_planico(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
A \code{\link{DiagnosticResult}} recording whether the diagnostic is present, the qualifying layers, and the supporting evidence.
}
\description{
Tipo especial de B textural com mudanca textural abrupta +
permeabilidade lenta + cores neutras/escurecidas + cromas baixos.
}
