% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-rsg-sibcs.R
\name{espodossolo}
\alias{espodossolo}
\title{Espodossolos (SiBCS Cap 4, p 112; conceito Cap 3, p 90-91)}
\usage{
espodossolo(pedon, max_top_cm = 200)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{max_top_cm}{Numeric threshold or option (see Details).}
}
\description{
Horizonte B espodico imediatamente abaixo de horizontes E ou A,
dentro de 200 cm (ou 400 cm se A+E ou histico+E ultrapassam 200).
}
