% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-rsg-sibcs.R
\name{vertissolo}
\alias{vertissolo}
\title{Vertissolos (SiBCS Cap 4, p 112; conceito Cap 3, p 105-106)}
\usage{
vertissolo(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Horizonte vertico iniciando \\<= 100 cm + clay \\>= 30\% nos 20 cm
superficiais + fendas verticais + ausencia de contato litico /
petrocalcico / duripa nos 30 cm + COLE \\>= 0.06.
}
