% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{test_designation_pattern}
\alias{test_designation_pattern}
\title{Test that a horizon designation matches a regex pattern}
\usage{
test_designation_pattern(h, pattern, candidate_layers = NULL)
}
\arguments{
\item{h}{Numeric threshold or option (see Details).}

\item{pattern}{A regex (case-insensitive).}

\item{candidate_layers}{Numeric threshold or option (see Details).}
}
\description{
Useful for diagnostics that key on field-described features
(e.g., glossic tongues for retic, R / Cr for leptic, "f" suffix
for cryic / frozen, hortic / irragric / plaggic / pretic / terric
for anthric).
}
