% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/report-html.R
\name{.soilkey_version}
\alias{.soilkey_version}
\title{Look up the package version, falling back gracefully when soilKey
is not installed (e.g. during interactive development with
`sys.source()`).}
\usage{
.soilkey_version()
}
\description{
Look up the package version, falling back gracefully when soilKey
is not installed (e.g. during interactive development with
`sys.source()`).
}
\keyword{internal}
