% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-atributos-sibcs.R
\name{subgrupo_plintossolo_endico_concrecionario}
\alias{subgrupo_plintossolo_endico_concrecionario}
\title{Subgrupo "endico" de Plintossolos Concrecionarios (topo de horizonte
concrecionario >= 40 cm)}
\usage{
subgrupo_plintossolo_endico_concrecionario(pedon, min_top_cm = 40)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_top_cm}{Profundidade minima inclusiva (default 40).}
}
\value{
\code{\link{DiagnosticResult}}.
}
\description{
Discrimina o Subgrupo FFcoEn (Plintossolos Petricos Concrecionarios
endicos): horizonte concrecionario cujo topo ocorre a >=
\code{min_top_cm} cm.
}
\references{
Embrapa (2018), SiBCS 5a ed., Cap 16, p 264.
}
