% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extdata-lazy-fetch.R
\name{.lazy_fetch_url}
\alias{.lazy_fetch_url}
\title{Build the GitHub Release download URL for a lazy-fetch cache}
\usage{
.lazy_fetch_url(name, release = .SOILKEY_LAZY_FETCH_RELEASE)
}
\description{
Build the GitHub Release download URL for a lazy-fetch cache
}
\keyword{internal}
