% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/afsp.R
\name{.afsp_unna}
\alias{.afsp_unna}
\title{Convert AfSP NoData sentinel (-9999) to NA}
\usage{
.afsp_unna(x)
}
\description{
Convert AfSP NoData sentinel (-9999) to NA
}
\keyword{internal}
