% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{fmt_num}
\alias{fmt_num}
\title{Format a numeric value with suffix, returning "NA" for NA/NULL}
\usage{
fmt_num(x, suffix = "", digits = 1)
}
\description{
Format a numeric value with suffix, returning "NA" for NA/NULL
}
\keyword{internal}
