% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{cec_per_clay}
\alias{cec_per_clay}
\title{CEC per kg clay (cmol_c)}
\usage{
cec_per_clay(cec_cmol, clay_pct)
}
\description{
\code{cec_cmol * 100 / clay_pct}. Returns \code{NA} when either input is
missing or \code{clay_pct <= 0}.
}
\keyword{internal}
