% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-fixtures-sibcs.R
\name{make_nitossolo_canonical}
\alias{make_nitossolo_canonical}
\title{Perfil canonico de Nitossolo Vermelho (SiBCS 5a ed., Cap 13)}
\usage{
make_nitossolo_canonical()
}
\value{
A \code{\link{PedonRecord}} populated with the canonical horizons and site metadata for this reference profile.
}
\description{
Solo argiloso (>= 35\% argila desde superficie) com B nitico
(estrutura forte em blocos + cerosidade), gradiente textural
baixo (B/A <= 1.5).
}
