% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-gelisols-usda.R
\name{spodic_subgroup_usda}
\alias{spodic_subgroup_usda}
\title{Spodic Subgroup helper for Psammorthels/Psammoturbels}
\usage{
spodic_subgroup_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Pass when a horizon >= 5 cm thick has any of:
\itemize{
  \item In >= 25\% of pedon, extremely weakly coherent or more
        coherent due to pedogenic cementation by OM and Al
        (with or without Fe); OR
  \item Al + 0.5 * Fe (oxalate) >= 0.25, and half that or less
        in an overlying horizon; OR
  \item ODOE >= 0.12, and value half as high or lower in an
        overlying horizon.
}
}
\details{
Implementation simplified to: any horizon with
(al_ox_pct + 0.5 * fe_ox_pct) >= 0.25 with an overlying layer
having <= half that value.
}
