% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-gelisols-usda.R
\name{sulfuric_horizon_usda}
\alias{sulfuric_horizon_usda}
\title{Sulfuric horizon helper (USDA, KST 13ed Ch 3)}
\usage{
sulfuric_horizon_usda(pedon, max_top_cm = 100, min_s_pct = 0.75)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{max_top_cm}{Default 100.}

\item{min_s_pct}{Default 0.75.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Pass when sulfidic_s_pct present in any horizon within
\code{max_top_cm} (proxy: KST sulfuric horizon requires pH < 4.0
OR sulfidic materials AND certain mottle colors; this v0.8 uses
sulfidic_s_pct >= 0.75 as proxy).
}
