% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redape.R
\name{.redape_extract_pred}
\alias{.redape_extract_pred}
\title{Extract the predicted label at a given SiBCS level from a classify_sibcs() result}
\usage{
.redape_extract_pred(res, level)
}
\description{
Extract the predicted label at a given SiBCS level from a classify_sibcs() result
}
\details{
The returned label is a \code{ClassificationResult} field
  for the requested level (Order / Subordem / Grande Grupo / Subgrupo).
}
\keyword{internal}
