% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/spectra-preprocess.R
\name{.sg_coefficients}
\alias{.sg_coefficients}
\title{Compute Savitzky-Golay coefficients for a derivative}
\usage{
.sg_coefficients(w, p, m)
}
\description{
Solves the standard SG least-squares system to derive the kernel
coefficients for a given window \code{w}, polynomial \code{p}, and
derivative order \code{m}. Used only when \code{prospectr} is
unavailable.
}
\keyword{internal}
