% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0963.R
\name{qual_transportic}
\alias{qual_transportic}
\title{Transportic qualifier (tr): transported material (Technosols / Regosols)}
\usage{
qual_transportic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
WRB 2022 Ch 5: "Soil material that has been moved by humans (mining
spoils, dredged sediments, roadside fill) covering >= 100 cm of
the upper soil." Detection via \code{layer_origin} matching
\code{transport|fill|spoil|dredge|aterro|antropico}.
}
