% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-histosols-usda.R
\name{smr_torric_usda}
\alias{smr_torric_usda}
\title{Torric soil moisture regime (USDA)}
\usage{
smr_torric_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Torric soil moisture regime (USDA)
}
