% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-rsg-sibcs.R
\name{argissolo}
\alias{argissolo}
\title{Argissolos (SiBCS Cap 4, p 114; conceito Cap 3, p 86-88)}
\usage{
argissolo(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Horizonte B textural -- catch-all final na chave SiBCS apos
Luvissolos / Nitossolos terem sido excluidos. v0.7 enforce: B
textural + (argila ativ baixa OR ativ alta + V baixa OR carater
alumínico).
}
