% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{test_esp_above}
\alias{test_esp_above}
\title{Test exchangeable sodium percentage above threshold}
\usage{
test_esp_above(h, min_pct = 15, candidate_layers = NULL)
}
\arguments{
\item{h}{Numeric threshold or option (see Details).}

\item{min_pct}{Numeric threshold or option (see Details).}

\item{candidate_layers}{Numeric threshold or option (see Details).}
}
\description{
Default 15\% (natric horizon, WRB 2022 Chapter 3).
}
