% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-fixtures-sibcs.R
\name{make_vertissolo_canonical}
\alias{make_vertissolo_canonical}
\title{Perfil canonico de Vertissolo (SiBCS 5a ed., Cap 17)}
\usage{
make_vertissolo_canonical()
}
\value{
A \code{\link{PedonRecord}} populated with the canonical horizons and site metadata for this reference profile.
}
\description{
Solo argiloso (>= 30\% argila desde superficie) com horizonte vertico
(slickensides + fendas + clay alto) iniciando dentro de 100 cm.
Reusa structure / fixture do WRB Vertisol.
}
