% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-rsg-sibcs.R
\name{latossolo}
\alias{latossolo}
\title{Latossolos (SiBCS Cap 4, p 113; conceito Cap 3, p 93-94)}
\usage{
latossolo(pedon, max_top_cm = 200)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{max_top_cm}{Numeric threshold or option (see Details).}
}
\description{
Horizonte B latossolico imediatamente abaixo de qualquer tipo de A
(exceto histico), dentro de 200 cm (ou 300 se A > 150 cm).
}
