% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/report-html.R
\name{.html_classification_card}
\alias{.html_classification_card}
\title{Render the per-result card (one per classification system).}
\usage{
.html_classification_card(res)
}
\description{
Render the per-result card (one per classification system).
}
\keyword{internal}
