% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{test_ph_below}
\alias{test_ph_below}
\title{Test that ph_h2o is at or below a threshold}
\usage{
test_ph_below(h, max_ph = 5.9, candidate_layers = NULL)
}
\arguments{
\item{h}{Numeric threshold or option (see Details).}

\item{max_ph}{Numeric threshold or option (see Details).}

\item{candidate_layers}{Numeric threshold or option (see Details).}
}
\description{
Default 5.9 (Spodic horizon supplementary criterion, WRB 2022).
}
