% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/engine-selection-v0965.R
\name{pick_engine_batch}
\alias{pick_engine_batch}
\title{Per-pedon batch engine recommendation}
\usage{
pick_engine_batch(pedons, min_score = 3L)
}
\arguments{
\item{pedons}{A list of \code{\link{PedonRecord}} objects.}

\item{min_score}{Integer; forwarded to \code{pick_engine}.}
}
\value{
Character vector of length(pedons) with values
  "aqp" or "soilkey".
}
\description{
Vectorised version of \code{\link{pick_engine}} returning the
recommended engine for each pedon in a list.
}
