% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v091de.R
\name{qual_cutanic}
\alias{qual_cutanic}
\title{Cutanic qualifier (ct): visible illuvial clay coatings on argic-
horizon ped surfaces (the "Cutanic Luvisol" / "Cutanic Argissol"
signature). v0.9.1: argic horizon passes AND the schema column
\code{clay_films_amount} contains "common", "many", or "continuous" (or
"shiny" -- common Brazilian descriptor for nitic surfaces) in some
argic layer.}
\usage{
qual_cutanic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Cutanic qualifier (ct): visible illuvial clay coatings on argic-
horizon ped surfaces (the "Cutanic Luvisol" / "Cutanic Argissol"
signature). v0.9.1: argic horizon passes AND the schema column
\code{clay_films_amount} contains "common", "many", or "continuous" (or
"shiny" -- common Brazilian descriptor for nitic surfaces) in some
argic layer.
}
