% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-gelisols-usda.R
\name{petrogypsic_horizon_usda}
\alias{petrogypsic_horizon_usda}
\title{Petrogypsic horizon helper (USDA)}
\usage{
petrogypsic_horizon_usda(pedon, max_top_cm = 100)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{max_top_cm}{Default 100.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Pass when a horizon has \code{cementation_class} in
\{strongly, indurated\} AND \code{caso4_pct >= 5} within
\code{max_top_cm}.
}
