% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/familia-sibcs.R
\name{familia_tipo_horizonte_superficial}
\alias{familia_tipo_horizonte_superficial}
\title{Familia: tipo de horizonte diagnostico superficial (Cap 2)}
\usage{
familia_tipo_horizonte_superficial(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
\code{\link{FamilyAttribute}}.
}
\description{
Retorna o tipo do horizonte A (ou H/O) presente, em ordem de
precedencia: \code{histico} > \code{chernozemico} >
\code{humico} > \code{proeminente} > \code{moderado} >
\code{fraco}. Se nenhum diagnostico passa, retorna NULL.
}
\details{
Aplica-se a TODAS as classes de solo, exceto para aquelas que
ja consideram o tipo de A em nivel categorico mais alto (e.g.
Chernossolos, Organossolos, Neossolos Litolicos Humicos /
Histicos).
}
\references{
Embrapa (2018), SiBCS 5a ed., Cap 2 (p 49-54);
            Cap 18, p 284.
}
