% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests-v04.R
\name{test_geomembrane_within_depth}
\alias{test_geomembrane_within_depth}
\title{Test for a continuous geomembrane within a depth window}
\usage{
test_geomembrane_within_depth(h, max_top_cm = 100)
}
\description{
WRB 2022 alternative for technic features: any layer with
\code{geomembrane_present == TRUE} within the upper
\code{max_top_cm}.
}
\keyword{internal}
