% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-horizons-sibcs.R
\name{horizonte_concrecionario}
\alias{horizonte_concrecionario}
\title{Horizonte concrecionario (SiBCS Cap 2, p 68-69; v0.7)}
\usage{
horizonte_concrecionario(
  pedon,
  min_petroplinthite_pct = 50,
  min_thickness = 30
)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_petroplinthite_pct}{Numeric threshold or option (see Details).}

\item{min_thickness}{Numeric threshold or option (see Details).}
}
\description{
\\>= 50\% volume material grosso (predominio petroplintita) numa
matriz, espessura \\>= 30 cm. Designation Ac/Ec/Bc/Cc.
}
