% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/febr.R
\name{.febr_match_layer_columns}
\alias{.febr_match_layer_columns}
\title{Map FEBR layer-table columns to soilKey horizon column names}
\usage{
.febr_match_layer_columns(cols)
}
\description{
Map FEBR layer-table columns to soilKey horizon column names
}
\keyword{internal}
