% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-vertisols-usda.R
\name{gypsic_subgroup_usda}
\alias{gypsic_subgroup_usda}
\title{Gypsic Subgroup helper -- delegates to gypsic_horizon_usda.}
\usage{
gypsic_subgroup_usda(pedon, max_top_cm = 100)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{max_top_cm}{Numeric threshold or option (see Details).}
}
\description{
Gypsic Subgroup helper -- delegates to gypsic_horizon_usda.
}
