% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{test_carbonates_present}
\alias{test_carbonates_present}
\title{Test for any layer with caco3_pct above a (low) threshold}
\usage{
test_carbonates_present(h, min_pct = 0.01, candidate_layers = NULL)
}
\arguments{
\item{h}{Numeric threshold or option (see Details).}

\item{min_pct}{Numeric threshold or option (see Details).}

\item{candidate_layers}{Numeric threshold or option (see Details).}
}
\description{
Default threshold is 0.01\% -- effectively "any measurable secondary
carbonate". Used to distinguish Phaeozems (no carbonates within 100
cm) from Chernozems and Kastanozems.
}
