% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0963.R
\name{qual_muusic}
\alias{qual_muusic}
\title{Muusic qualifier (mu): high-fibre peat (non-moss-specific)}
\usage{
qual_muusic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
WRB 2022 Ch 5 (Histosols): "Containing >= 75\% by volume rubbed
fibres in organic material >= 40 cm thick within 100 cm."
}
