% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-horizons-sibcs.R
\name{horizonte_A_chernozemico}
\alias{horizonte_A_chernozemico}
\title{Horizonte A chernozemico (SiBCS Cap 2, p 50-51)}
\usage{
horizonte_A_chernozemico(
  pedon,
  min_oc_g_kg = 6,
  min_v_pct = 65,
  max_value_moist = 3,
  max_chroma_moist = 3,
  max_value_dry = 5,
  min_thickness_cm = 18
)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_oc_g_kg}{Numeric threshold or option (see Details).}

\item{min_v_pct}{Numeric threshold or option (see Details).}

\item{max_value_moist}{Numeric threshold or option (see Details).}

\item{max_chroma_moist}{Numeric threshold or option (see Details).}

\item{max_value_dry}{Numeric threshold or option (see Details).}

\item{min_thickness_cm}{Numeric threshold or option (see Details).}
}
\description{
Horizonte mineral superficial relativamente espesso, escuro, com
alta saturacao por bases (V \\>= 65\%), OC \\>= 6 g/kg, estrutura
desenvolvida e espessura conforme criterio.
}
