% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-atributos-sibcs.R
\name{carater_petroplintico}
\alias{carater_petroplintico}
\title{Carater petroplintico (SiBCS Cap 5)}
\usage{
carater_petroplintico(pedon, max_depth_cm = 150)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{max_depth_cm}{Default 150 cm.}
}
\value{
\code{\link{DiagnosticResult}}.
}
\description{
Caracteres concrecionario e/ou litoplintico ou horizontes
concrecionario / litoplintico em posicao NAO diagnostica para
Plintossolos Petricos, dentro de \code{max_depth_cm} (default 150).
Discrimina os Subgrupos petroplinticos de Argissolos (Cap 5: PA, PVA,
PV).
}
\details{
Implementacao: passa se \code{\link{horizonte_concrecionario}} OU
\code{\link{horizonte_litoplintico}} retornarem TRUE em ao menos
uma camada com top < max_depth_cm.
}
\references{
Embrapa (2018), SiBCS 5a ed., Cap 5; Cap 16
            (Plintossolos).
}
