% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0964.R
\name{qual_bryic}
\alias{qual_bryic}
\title{Bryic supplementary qualifier (by): bryophyte cover at surface}
\usage{
qual_bryic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
WRB 2022 Ch 5: "Predominant bryophyte (moss / liverwort) ground
cover." Implementation: \code{layer_origin} matches moss / lichen
pattern OR \code{vegetation_cover} site field >= 50.
}
