% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/febr.R
\name{.febr_rows_to_horizons}
\alias{.febr_rows_to_horizons}
\title{Build a soilKey horizons table from a subset of FEBR camada rows}
\usage{
.febr_rows_to_horizons(rows, sk_map, mcols)
}
\description{
Build a soilKey horizons table from a subset of FEBR camada rows
}
\keyword{internal}
