% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{test_cec_per_clay_above}
\alias{test_cec_per_clay_above}
\title{Test that CEC per kg clay is at or above a threshold}
\usage{
test_cec_per_clay_above(h, min_cmol_per_kg_clay = 24, candidate_layers = NULL)
}
\arguments{
\item{h}{Numeric threshold or option (see Details).}

\item{min_cmol_per_kg_clay}{Numeric threshold or option (see Details).}

\item{candidate_layers}{Numeric threshold or option (see Details).}
}
\description{
Default 24 cmol_c/kg clay -- WRB 2022 boundary that distinguishes
"low-activity-clay" RSGs (Acrisols, Lixisols) from "high-activity-
clay" RSGs (Alisols, Luvisols).
}
