% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-gelisols-usda.R
\name{thapto_humic_usda}
\alias{thapto_humic_usda}
\title{Thapto-Humic Subgroup helper}
\usage{
thapto_humic_usda(
  pedon,
  max_top_cm = 200,
  min_thickness_cm = 20,
  min_oc_pct = 1
)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{max_top_cm}{Default 200.}

\item{min_thickness_cm}{Default 20.}

\item{min_oc_pct}{Default 1.0.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Pass when a buried layer meets criteria for histic, mollic,
umbric, or melanic epipedon within 200 cm of the soil surface,
OR buried O and dark-colored A horizons (V <= 3 moist, combined
thickness >= 20 cm, OC >= 1 percent Holocene-age) within 200 cm
(KST 13ed, p 189-191).
}
\details{
Implementation detects buried horizons via designation containing
'b' (KST notation for buried) AND dark color (V <= 3) within 200 cm.
}
\references{
Soil Survey Staff (2022), KST 13ed, Ch. 9 various.
}
