% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bdsolos.R
\name{.bdsolos_detect_sep}
\alias{.bdsolos_detect_sep}
\title{Auto-detect the BDsolos field separator (`,`, `;`, or tab)}
\usage{
.bdsolos_detect_sep(path, header_line = 1L)
}
\description{
Auto-detect the BDsolos field separator (`,`, `;`, or tab)
}
\keyword{internal}
