% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-horizons-sibcs.R
\name{horizonte_plintico}
\alias{horizonte_plintico}
\title{Horizonte plintico (SiBCS Cap 2, p 67-68; v0.7)}
\usage{
horizonte_plintico(pedon, min_plinthite_pct = 15, min_thickness = 15)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_plinthite_pct}{Numeric threshold or option (see Details).}

\item{min_thickness}{Numeric threshold or option (see Details).}
}
\description{
Plintita \\>= 15\% volume, espessura \\>= 15 cm. Tem precedencia
sobre B textural, latossolico, nitico, B incipiente, planico (sem
carater sodico), e glei. Reuso de \code{\link{plinthic}} (WRB).
}
