% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0964.R
\name{qual_neocambic}
\alias{qual_neocambic}
\title{Neocambic qualifier (nc): "young" cambic horizon with weak development}
\usage{
qual_neocambic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
WRB 2022 Ch 5 (Retisols): "Cambic horizon with structure_grade
\"weak\" only (early-stage pedogenesis)." Composite: cambic + weak
structure.
}
