% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0964.R
\name{qual_geoabruptic}
\alias{qual_geoabruptic}
\title{Geoabruptic supplementary qualifier (ga): abrupt change at lithological boundary
WRB 2022 Ch 5: "Abrupt textural / mineralogical change at a
lithological discontinuity (e.g., 2C horizon below B)."
Implementation: designation pattern containing "2C" or "3C"
(numeric prefix indicates lithologic discontinuity).}
\usage{
qual_geoabruptic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Geoabruptic supplementary qualifier (ga): abrupt change at lithological boundary
WRB 2022 Ch 5: "Abrupt textural / mineralogical change at a
lithological discontinuity (e.g., 2C horizon below B)."
Implementation: designation pattern containing "2C" or "3C"
(numeric prefix indicates lithologic discontinuity).
}
