% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-histosols-usda.R
\name{fibric_subgroup_usda}
\alias{fibric_subgroup_usda}
\title{Fibric Subgroup helper (Haplohemists / Haplowassists / Sulfiwassists)
Pass when fibric layers cumulative thickness >= 25 cm in control
section below surface tier.}
\usage{
fibric_subgroup_usda(pedon, max_top_cm = 130)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{max_top_cm}{Numeric threshold or option (see Details).}
}
\description{
Fibric Subgroup helper (Haplohemists / Haplowassists / Sulfiwassists)
Pass when fibric layers cumulative thickness >= 25 cm in control
section below surface tier.
}
