% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{test_clay_above}
\alias{test_clay_above}
\title{Test that clay_pct is at or above a threshold}
\usage{
test_clay_above(h, min_pct = 30, candidate_layers = NULL)
}
\arguments{
\item{h}{Numeric threshold or option (see Details).}

\item{min_pct}{Numeric threshold or option (see Details).}

\item{candidate_layers}{Numeric threshold or option (see Details).}
}
\description{
Default 30\% (vertic features minimum, WRB 2022 Chapter 3).
}
