% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/familia-sibcs.R
\name{familia_organossolo_lenhosidade}
\alias{familia_organossolo_lenhosidade}
\title{Familia: lenhosidade em Organossolos (Cap 18, p 288)}
\usage{
familia_organossolo_lenhosidade(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
\code{\link{FamilyAttribute}}.
}
\description{
Classifica a presenca de galhos / fragmentos de troncos > 2 cm em
camadas organicas, "a semelhanca do utilizado para qualificar
as classes de pedregosidade" (Cap 18 p 288):
\itemize{
  \item \code{lenhoso}: 10\% <= woody_fragments < 30\%
  \item \code{muito_lenhoso}: 30\% <= woody_fragments <= 50\%
  \item \code{extremamente_lenhoso}: woody_fragments > 50\%
}
(Limites adotados a partir das classes de pedregosidade,
Santos et al. 2015.)
}
\references{
Embrapa (2018), SiBCS 5a ed., Cap 18, p 288.
}
