% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{test_fe_dcb_above}
\alias{test_fe_dcb_above}
\title{Test for high free-iron content (\code{fe_dcb_pct} >= threshold)}
\usage{
test_fe_dcb_above(h, min_pct = 4, candidate_layers = NULL)
}
\arguments{
\item{h}{Numeric threshold or option (see Details).}

\item{min_pct}{Numeric threshold or option (see Details).}

\item{candidate_layers}{Numeric threshold or option (see Details).}
}
\description{
Default 4\% (an indicator of strong red colour and Fe-richness; used
as a v0.3 simplified marker for nitic horizon's typical Fe content).
}
