% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests-v033.R
\name{test_yermic_surface}
\alias{test_yermic_surface}
\title{Test for WRB 2022 Ch 3.2.17 yermic surface signature}
\usage{
test_yermic_surface(h)
}
\description{
Coarse surface fragments (\code{desert_pavement_pct}) >= 20\% AND
(\code{varnish_pct} >= 10 OR \code{ventifact_pct} >= 10 OR
\code{vesicular_pores} \%in\% c("common", "many")) on the surface
layer (top_cm <= 5).
}
\keyword{internal}
