% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-atributos-sibcs.R
\name{carater_perferrico}
\alias{carater_perferrico}
\title{Carater perferrico (SiBCS Cap 1; Cap 6 CX Perferricos)}
\usage{
carater_perferrico(pedon, min_fe2o3_pct = 36, max_depth_cm = 100)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_fe2o3_pct}{Limite inferior em \% mass (default 36 = 360 g/kg).}

\item{max_depth_cm}{Profundidade maxima de B avaliado (default 100).}
}
\value{
\code{\link{DiagnosticResult}}.
}
\description{
Teor de Fe2O3 (pelo ataque sulfurico-NaOH) >= 360 g/kg de solo
(= 36\%) na maior parte dos primeiros 100 cm do horizonte B.
Discrimina os Grandes Grupos Perferricos (acima do range
"ferrico" 180-360 g/kg). Cap 6 CX 4.3 e Cap 10 (Latossolos
Perferricos).
}
\references{
Embrapa (2018), SiBCS 5a ed., Cap 1; Cap 6, p 142;
            Cap 10 (Latossolos Perferricos).
}
