% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v092a.R
\name{qual_hypogypsic}
\alias{qual_hypogypsic}
\title{Hypogypsic qualifier (jg): gypsum >= 1\% AND < 5\% in some layer
within 100 cm (below the gypsic-horizon threshold but above the
protogypsic-properties bare-detection bar).}
\usage{
qual_hypogypsic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Hypogypsic qualifier (jg): gypsum >= 1\% AND < 5\% in some layer
within 100 cm (below the gypsic-horizon threshold but above the
protogypsic-properties bare-detection bar).
}
