% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/key-sibcs.R
\name{run_sibcs_key}
\alias{run_sibcs_key}
\title{Roda a chave SiBCS 5a edicao sobre um pedon}
\usage{
run_sibcs_key(pedon, rules = NULL)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{rules}{Conjunto de regras pre-carregado; se NULL, le
\code{inst/rules/sibcs5/key.yaml}.}
}
\value{
Lista com \code{assigned} (entrada YAML da ordem atribuida)
        e \code{trace}.
}
\description{
Roda a chave SiBCS 5a edicao sobre um pedon
}
