% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests-v04.R
\name{test_volcanic_glass_above}
\alias{test_volcanic_glass_above}
\title{Test volcanic glass content above threshold}
\usage{
test_volcanic_glass_above(h, min_pct = 30, candidate_layers = NULL)
}
\description{
WRB 2022 alternative for andic properties: glass content >= 30 \%
in the 0.02--2 mm sand fraction.
}
\keyword{internal}
