% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{make_empty_provenance}
\alias{make_empty_provenance}
\title{Empty provenance table}
\usage{
make_empty_provenance()
}
\description{
Empty provenance table
}
\keyword{internal}
