% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-horizons-wrb-v033.R
\name{ferric}
\alias{ferric}
\title{Ferric horizon (WRB 2022)}
\usage{
ferric(pedon, min_thickness = 15, min_fe_dith_pct = 5)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_thickness}{Minimum thickness (cm; default 15).}

\item{min_fe_dith_pct}{Minimum dithionite-extractable iron percent (default 5).}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
A horizon of iron accumulation that does not reach the cementation /
redness levels of plinthic. Diagnostic for the Ferric qualifier.
}
\references{
IUSS Working Group WRB (2022), Chapter 3.1, Ferric horizon.
}
