% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-fixtures.R
\name{make_durisol_canonical}
\alias{make_durisol_canonical}
\title{Build the canonical Durisol fixture}
\usage{
make_durisol_canonical()
}
\value{
A \code{\link{PedonRecord}}.
}
\description{
Synthetic semi-arid Durisol with a Si-cemented subsurface horizon
(35\% duripan nodules over 45 cm). By construction
\code{\link{duric_horizon}} passes on Bdu.
}
