% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v093b.R
\name{qual_profondic}
\alias{qual_profondic}
\title{Profondic qualifier (pf): argic horizon that continues, with no
clay decrease, down to or below 150 cm.
v0.9.3.B: requires \code{argic} to pass AND at least one argic
layer with \code{bottom_cm >= 150}.}
\usage{
qual_profondic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Profondic qualifier (pf): argic horizon that continues, with no
clay decrease, down to or below 150 cm.
v0.9.3.B: requires \code{argic} to pass AND at least one argic
layer with \code{bottom_cm >= 150}.
}
