% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-gelisols-usda.R
\name{argillic_within_usda}
\alias{argillic_within_usda}
\title{Argillic horizon helper (USDA, KST 13ed Ch 3)}
\usage{
argillic_within_usda(pedon, max_top_cm = 100)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{max_top_cm}{Default 100 cm.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Wrapper around argillic_usda that simply re-exports the
DiagnosticResult with a max-depth check (default 100 cm for
Argiorthels Subgroup keys).
}
