% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-rsg-sibcs.R
\name{organossolo}
\alias{organossolo}
\title{Organossolos (SiBCS Cap 4, chave do 1o nivel; conceito Cap 3, p 99-101)}
\usage{
organossolo(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Solos com horizonte hístico atendendo a um dos criterios de
espessura: \\>= 20 cm sobre rocha, \\>= 40 cm continuo OR cumulativo
nos 80 cm superficiais, OR \\>= 60 cm se \\>= 75\% volume tecido
vegetal.
}
