% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-andisols-usda.R
\name{fulvic_andisol_usda}
\alias{fulvic_andisol_usda}
\title{Fulvic Andisols: similar to melanic but with melanic_index > 1.70
(more humic acid). v0.8: detected via OC >= 6 in cumulative 30 cm
but WITHOUT melanic_epipedon (since melanic requires index <= 1.70).}
\usage{
fulvic_andisol_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Fulvic Andisols: similar to melanic but with melanic_index > 1.70
(more humic acid). v0.8: detected via OC >= 6 in cumulative 30 cm
but WITHOUT melanic_epipedon (since melanic requires index <= 1.70).
}
