% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v091c.R
\name{qual_placic}
\alias{qual_placic}
\title{Placic qualifier (pi): thin (<= 25 mm = 2.5 cm) cemented Fe pan,
typically inside or just above a spodic horizon. v0.9.1: a layer
with cementation_class strongly or indurated AND thickness <= 2.5 cm,
anywhere in the upper 100 cm.}
\usage{
qual_placic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Placic qualifier (pi): thin (<= 25 mm = 2.5 cm) cemented Fe pan,
typically inside or just above a spodic horizon. v0.9.1: a layer
with cementation_class strongly or indurated AND thickness <= 2.5 cm,
anywhere in the upper 100 cm.
}
