% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0964.R
\name{qual_cordic}
\alias{qual_cordic}
\title{Cordic supplementary qualifier (cd): cordic horizon}
\usage{
qual_cordic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
WRB 2022 Ch 5: "Cemented horizon NOT meeting duripan / petrocalcic /
petrogypsic criteria but slacks moderately in water." Detection via
\code{cordic_horizon} TRUE/FALSE schema flag.
}
