% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{test_ferralic_thickness}
\alias{test_ferralic_thickness}
\title{Ferralic minimum thickness >= 30 cm (WRB 2022)}
\usage{
test_ferralic_thickness(h, min_cm = 30, candidate_layers = NULL)
}
\arguments{
\item{h}{Numeric threshold or option (see Details).}

\item{min_cm}{Numeric threshold or option (see Details).}

\item{candidate_layers}{Numeric threshold or option (see Details).}
}
\description{
Wraps \code{\link{test_minimum_thickness}}.
}
