% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v091.R
\name{qual_sapric}
\alias{qual_sapric}
\title{Sapric qualifier (sa): organic material whose dominant decomposition
class in the upper 100 cm is sapric (rubbed fiber < 1/6).
v0.9.1: thickness-weighted dominance via Oa designation.}
\usage{
qual_sapric(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Sapric qualifier (sa): organic material whose dominant decomposition
class in the upper 100 cm is sapric (rubbed fiber < 1/6).
v0.9.1: thickness-weighted dominance via Oa designation.
}
