% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/familia-sibcs.R
\name{familia_organossolo_espessura}
\alias{familia_organossolo_espessura}
\title{Familia: espessura > 100 cm de material organico em Organossolos
(Cap 18, p 287)}
\usage{
familia_organossolo_espessura(pedon, min_cm = 100)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_cm}{Default 100 cm.}
}
\value{
\code{\link{FamilyAttribute}}.
}
\description{
Retorna \code{"espesso"} quando a soma das espessuras de
camadas organicas a partir da superficie excede 100 cm
(Cap 18 p 287: "Organossolos com mais de 100 cm de material
organico a partir da sua superficie").
}
\references{
Embrapa (2018), SiBCS 5a ed., Cap 18, p 287.
}
