% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-spodosols-usda.R
\name{duripan_usda}
\alias{duripan_usda}
\title{Duripan (USDA, KST 13ed Ch 3, pp 36-37)}
\usage{
duripan_usda(pedon, max_top_cm = 100)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{max_top_cm}{Default 100.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Silica-cemented horizon, very strongly resistant. Detected via
\code{cementation_class == "indurated"} AND \code{duripan_pct
>= 50}.
}
