% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redape.R
\name{.redape_horizon_to_soilkey}
\alias{.redape_horizon_to_soilkey}
\title{Convert one Redape GeoTab horizon record to a soilKey horizon row}
\usage{
.redape_horizon_to_soilkey(h)
}
\description{
Convert one Redape GeoTab horizon record to a soilKey horizon row
}
\keyword{internal}
