% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-fixtures-sibcs.R
\name{make_latossolo_canonical}
\alias{make_latossolo_canonical}
\title{Perfil canonico de Latossolo (SiBCS 5a ed., Cap 10)}
\usage{
make_latossolo_canonical()
}
\description{
Reusa fixture WRB Ferralsol -- B latossolico imediatamente abaixo
de A, sem horizonte argilico acima.
}
