% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0963.R
\name{qual_endocalcaric}
\alias{qual_endocalcaric}
\title{Endocalcaric qualifier (cae): calcaric only at depth >= 50 cm}
\usage{
qual_endocalcaric(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
WRB 2022 Ch 5 (Umbrisols / Retisols): "Calcaric material starting
>= 50 cm from the soil surface." Modifier of
\code{\link{calcaric_material}}.
}
