% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0964.R
\name{qual_capillaric}
\alias{qual_capillaric}
\title{Capillaric supplementary qualifier (cp): capillary rise zone
WRB 2022 Ch 5: "Capillary rise from a shallow water table to within
50 cm of the soil surface; flagged via redox concentrations (>=2\%) +
fine texture (clay+silt > 50\%)."}
\usage{
qual_capillaric(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Capillaric supplementary qualifier (cp): capillary rise zone
WRB 2022 Ch 5: "Capillary rise from a shallow water table to within
50 cm of the soil surface; flagged via redox concentrations (>=2\%) +
fine texture (clay+silt > 50\%)."
}
