% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/report-html.R
\name{.html_head}
\alias{.html_head}
\title{Render the head section with embedded CSS.}
\usage{
.html_head(title)
}
\description{
Render the head section with embedded CSS.
}
\keyword{internal}
