% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/benchmark-unified.R
\name{.benchmark_one_dataset_one_system}
\alias{.benchmark_one_dataset_one_system}
\title{Single (dataset, system) benchmark call dispatched by name}
\usage{
.benchmark_one_dataset_one_system(
  ds,
  sys,
  paths,
  max_n,
  harmonize = FALSE,
  verbose = TRUE
)
}
\description{
Single (dataset, system) benchmark call dispatched by name
}
\keyword{internal}
