% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-atributos-sibcs.R
\name{subgrupo_planossolo_mesicos}
\alias{subgrupo_planossolo_mesicos}
\title{Subgrupo "mesicos" de Planossolos (B planico topo em [50, 100] cm)}
\usage{
subgrupo_planossolo_mesicos(pedon, min_top_cm = 50, max_top_cm = 100)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_top_cm}{Profundidade minima inclusiva (default 50).}

\item{max_top_cm}{Profundidade maxima inclusiva (default 100).}
}
\value{
\code{\link{DiagnosticResult}}.
}
\description{
Discrimina os Subgrupos mesicos de Planossolos (Cap 15:
SNs Mesicos, SNo Mesicos, SXs Mesicos, SXal Mesicos, SXd Mesicos,
SXe Mesicos): B planico cujo topo ocorre entre \code{min_top_cm}
(inclusivo) e \code{max_top_cm} (inclusivo).
}
\references{
Embrapa (2018), SiBCS 5a ed., Cap 15 (Planossolos).
}
