% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-histosols-usda.R
\name{histosol_qualifying_usda}
\alias{histosol_qualifying_usda}
\title{Histosols Order qualifier (USDA, KST 13ed, Ch 2, p 7)}
\usage{
histosol_qualifying_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Organic soils not meeting the Gelisols requirements (no permafrost
within 100 cm). The KST defines Histosols as soils with organic
soil materials that meet specific thickness/depth criteria
(Ch 2, pp 7-9; see also Ch 3 organic soil materials).
}
\details{
Implementation: pass when cumulative organic-layer thickness
(designation H or O) within 0-100 cm >= 40 cm AND no permafrost
within 100 cm.
}
\references{
Soil Survey Staff (2022), KST 13ed, Ch. 2, pp 7-9.
}
