% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-gelisols-usda.R
\name{andic_subgroup_usda}
\alias{andic_subgroup_usda}
\title{Andic Subgroup helper (USDA, KST 13ed)}
\usage{
andic_subgroup_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Pass when, throughout one or more horizons with total thickness
>= 18 cm within 75 cm of the surface:
\itemize{
  \item bulk_density_g_cm3 <= 1.0 (at 33 kPa); AND
  \item Al + 0.5 * Fe (oxalate-extractable) > 1.0 percent.
}
KST 13ed, p 117 (Andisols core, applies to subgroup criteria too).
}
