% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-spodosols-usda.R
\name{kandic_horizon_usda}
\alias{kandic_horizon_usda}
\title{Kandic horizon (USDA, KST 13ed Ch 3, p 45)}
\usage{
kandic_horizon_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Subsurface horizon with low-activity clays (CEC <= 16 cmol/kg
clay, ECEC <= 12) and clay increase. Implementation:
delegates to argic with additional CEC/clay check.
}
