% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-fixtures-sibcs.R
\name{make_neossolo_canonical}
\alias{make_neossolo_canonical}
\title{Perfil canonico de Neossolo Litolico (SiBCS 5a ed., Cap 12)}
\usage{
make_neossolo_canonical()
}
\description{
Solo raso sobre rocha continua dura. Sem horizonte B diagnostico.
}
