% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/report-html.R
\name{.html_escape}
\alias{.html_escape}
\title{Internal helper: .html_escape}
\usage{
.html_escape(x)
}
\description{
Internal helper: .html_escape
}
\keyword{internal}
