% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/benchmark-unified.R
\name{.merge_confusion}
\alias{.merge_confusion}
\title{Merge two confusion matrices (table objects), padding union of labels}
\usage{
.merge_confusion(a, b)
}
\description{
Merge two confusion matrices (table objects), padding union of labels
}
\keyword{internal}
