% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0963.R
\name{qual_orthofluvic}
\alias{qual_orthofluvic}
\title{Orthofluvic qualifier (of): fluvic material 50-100 cm}
\usage{
qual_orthofluvic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
WRB 2022 Ch 5 (Fluvisols): "Fluvic material with its upper boundary
between 50 and 100 cm of the soil surface." (default Fluvisol qualifier
when neither Ano- nor Panto- applies.)
}
