% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-horizons-sibcs.R
\name{horizonte_A_proeminente}
\alias{horizonte_A_proeminente}
\title{Horizonte A proeminente (SiBCS Cap 2, p 52-53)}
\usage{
horizonte_A_proeminente(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Como A chernozemico (cor escura, OC >= 6 g/kg) **mas com V < 65\%**.
}
