% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-atributos-sibcs.R
\name{carater_rubrico}
\alias{carater_rubrico}
\title{Carater rubrico (SiBCS Cap 1; Cap 10 Latossolos Brunos)}
\usage{
carater_rubrico(pedon, min_chroma = 4, max_depth_cm = 100)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_chroma}{Default 4.}

\item{max_depth_cm}{Default 100.}
}
\value{
\code{\link{DiagnosticResult}}.
}
\description{
Solos com matiz Munsell mais vermelho que 5YR (i.e., 2.5YR, 10R, 5R)
E chroma \eqn{\ge} 4 em alguma parte do horizonte B (inclusive BA),
dentro de \code{max_depth_cm} (default 100). Discrimina os Subgrupos
rubricos de Latossolos Brunos (Cap 10 LB).
}
\references{
Embrapa (2018), SiBCS 5a ed., Cap 1; Cap 10 LB, p 199-200.
}
