% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-atributos-sibcs.R
\name{carater_redoxico}
\alias{carater_redoxico}
\title{Carater redoxico (SiBCS Cap 1, p 36-37): feicoes redoximorficas
em quantidade pelo menos comum, dentro da secao de controle.
\code{epirredoxico} se dentro de 50 cm; \code{endorredoxico} se
50-150 cm.}
\usage{
carater_redoxico(pedon, min_redox_pct = 5, max_top_cm = 150)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_redox_pct}{Numeric threshold or option (see Details).}

\item{max_top_cm}{Numeric threshold or option (see Details).}
}
\description{
Carater redoxico (SiBCS Cap 1, p 36-37): feicoes redoximorficas
em quantidade pelo menos comum, dentro da secao de controle.
\code{epirredoxico} se dentro de 50 cm; \code{endorredoxico} se
50-150 cm.
}
