% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-oxisols-usda.R
\name{humic_oxisol_usda}
\alias{humic_oxisol_usda}
\title{Humic-Oxisol Subgroup helper
Pass when cumulative organic carbon mass is >= 16 kg/m2 between
surface and 100 cm (computed as SUM(OC\% * bulk_density * dz)).
v0.8 proxy: uses default bulk_density 1.0 g/cm3 if unavailable.}
\usage{
humic_oxisol_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Humic-Oxisol Subgroup helper
Pass when cumulative organic carbon mass is >= 16 kg/m2 between
surface and 100 cm (computed as SUM(OC\% * bulk_density * dz)).
v0.8 proxy: uses default bulk_density 1.0 g/cm3 if unavailable.
}
