% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0964.R
\name{qual_activic}
\alias{qual_activic}
\title{Activic supplementary qualifier (av): active aluminium >= 5 cmol/kg
WRB 2022 Ch 5: "KCl-extractable Al (\code{al_kcl_cmol}) >= 5
cmol(c)/kg in any layer in upper 100 cm." Proxy via existing
\code{al_cmol} (exchangeable Al) when al_kcl_cmol absent.}
\usage{
qual_activic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Activic supplementary qualifier (av): active aluminium >= 5 cmol/kg
WRB 2022 Ch 5: "KCl-extractable Al (\code{al_kcl_cmol}) >= 5
cmol(c)/kg in any layer in upper 100 cm." Proxy via existing
\code{al_cmol} (exchangeable Al) when al_kcl_cmol absent.
}
