% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests-v04.R
\name{test_phosphate_retention_above}
\alias{test_phosphate_retention_above}
\title{Test phosphate retention above threshold}
\usage{
test_phosphate_retention_above(h, min_pct = 70, candidate_layers = NULL)
}
\description{
WRB 2022 alternative for andic properties: P retention >= 70 \%.
}
\keyword{internal}
