% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{test_caco3_concentration}
\alias{test_caco3_concentration}
\title{Test for CaCO3 concentration above threshold (per layer)}
\usage{
test_caco3_concentration(h, min_pct = 15, candidate_layers = NULL)
}
\arguments{
\item{h}{Numeric threshold or option (see Details).}

\item{min_pct}{Numeric threshold or option (see Details).}

\item{candidate_layers}{Numeric threshold or option (see Details).}
}
\description{
Default 15\% (calcic horizon, WRB 2022 Chapter 3). Used by
\code{\link{calcic}}.
}
