% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{test_slickensides_present}
\alias{test_slickensides_present}
\title{Test for slickensides at or above a presence level}
\usage{
test_slickensides_present(
  h,
  levels = c("common", "many", "continuous"),
  candidate_layers = NULL
)
}
\arguments{
\item{h}{Numeric threshold or option (see Details).}

\item{levels}{Numeric threshold or option (see Details).}

\item{candidate_layers}{Numeric threshold or option (see Details).}
}
\description{
Default accepted levels are \code{c("common", "many", "continuous")}
(vertic features, WRB 2022). The \code{slickensides} column accepts
\code{c("absent", "few", "common", "many", "continuous")}.
}
