% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-atributos-sibcs.R
\name{carater_cambissolico}
\alias{carater_cambissolico}
\title{Carater cambissolico (SiBCS Cap 14)}
\usage{
carater_cambissolico(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
\code{\link{DiagnosticResult}}.
}
\description{
Solos com B incipiente (\code{\link{B_incipiente}}) abaixo do
horizonte hístico (H/O) ou A. Discrimina os Subgrupos cambissolicos
de Organossolos Folicos (Cap 14, pp 247-248): Folicos Fibricos /
Hemicos / Sapricos cambissolicos.
}
\details{
Implementado como uma interseccao de duas condicoes:
\enumerate{
  \item \code{B_incipiente} passa em ao menos um horizonte
  \item Esse horizonte B incipiente esta abaixo de um horizonte
        H/O (hístico) ou A
}
Em pedons sem H/O ou A acima do B incipiente, o teste falha
(B incipiente isolado nao caracteriza Organossolo Cambissolico).
}
\references{
Embrapa (2018), SiBCS 5a ed., Cap 14, pp 247-248.
}
