% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{provenance_authority}
\alias{provenance_authority}
\title{Authority order for provenance sources}
\usage{
provenance_authority(source)
}
\description{
Higher value = more authoritative. Used when reconciling values from
multiple sources (e.g. measured beats predicted_spectra beats
extracted_vlm beats inferred_prior beats user_assumed).
}
\keyword{internal}
