% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022.R
\name{qual_folic}
\alias{qual_folic}
\title{Folic qualifier (fo): folic horizon at the soil surface. v0.9
delegates to histic_horizon with surface-only filter.}
\usage{
qual_folic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Folic qualifier (fo): folic horizon at the soil surface. v0.9
delegates to histic_horizon with surface-only filter.
}
