% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-fixtures-sibcs.R
\name{make_espodossolo_canonical}
\alias{make_espodossolo_canonical}
\title{Perfil canonico de Espodossolo (SiBCS 5a ed., Cap 8)}
\usage{
make_espodossolo_canonical()
}
\description{
Reusa fixture WRB Podzol -- B espodico imediatamente abaixo de E.
}
