% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/soil-classes-at-location.R
\name{.typical_attribute_table}
\alias{.typical_attribute_table}
\title{Canonical attribute ranges per class, used as the
"what-to-confirm" appendix.}
\usage{
.typical_attribute_table(system, codes)
}
\description{
Canonical attribute ranges per class, used as the
"what-to-confirm" appendix.
}
\keyword{internal}
