% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0964.R
\name{qual_mahic}
\alias{qual_mahic}
\title{Mahic supplementary qualifier (mh): manure-derived dark surface
WRB 2022 Ch 5: "Topsoil enriched by long-term manure / compost
application; oc_pct >= 4\%, base_saturation_pct >= 50\%, and
p_mehlich >= 100 mg/kg."}
\usage{
qual_mahic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Mahic supplementary qualifier (mh): manure-derived dark surface
WRB 2022 Ch 5: "Topsoil enriched by long-term manure / compost
application; oc_pct >= 4\%, base_saturation_pct >= 50\%, and
p_mehlich >= 100 mg/kg."
}
