% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0963.R
\name{qual_greyzemic}
\alias{qual_greyzemic}
\title{Greyzemic qualifier (gz): mollic / umbric overlain by albic-like layer}
\usage{
qual_greyzemic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
WRB 2022 Ch 5 (Chernozems / Phaeozems / Umbrisols): "Having a
mollic / umbric horizon overlain by a thin (<= 10 cm) albic-like
layer with low chroma and high value (Munsell value >= 4 moist
AND chroma <= 2)."
}
\details{
Implementation: presence of mollic OR umbric (we have
\code{\link{mollic}} but not yet \code{umbric}) AND an overlying
bleached layer (\code{munsell_value_moist >= 4} and
\code{munsell_chroma_moist <= 2}, thickness <= 10 cm).
}
