% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-gelisols-usda.R
\name{vitrandic_subgroup_usda}
\alias{vitrandic_subgroup_usda}
\title{Vitrandic Subgroup helper (USDA, KST 13ed)}
\usage{
vitrandic_subgroup_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Pass when, throughout one or more horizons with total thickness
>= 18 cm within 75 cm of the surface, BOTH:
\itemize{
  \item More than 35\% (volume) particles >= 2 mm of which
        > 66\% are cinders/pumice; OR fine-earth has >= 30\%
        particles 0.02-2 mm AND >= 5\% volcanic glass (in 0.02-2 mm); AND
  \item (Al + 0.5 * Fe) * 60 + volcanic_glass_pct >= 30.
}
KST 13ed, Ch 9 various.
}
\details{
Implementation simplified to the volcanic-glass branch:
volcanic_glass_pct >= 5 AND (Al + 0.5 * Fe) * 60 + volcanic_glass_pct >= 30.
}
