% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-atributos-sibcs.R
\name{carater_chernossolico}
\alias{carater_chernossolico}
\title{Carater chernossolico (SiBCS Cap 5; A chernozemico + Ta alta)}
\usage{
carater_chernossolico(pedon, min_ta = 20)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_ta}{Threshold de atividade da argila (default 20).}
}
\value{
\code{\link{DiagnosticResult}}.
}
\description{
Solos com horizonte A chernozemico
(\code{\link{horizonte_A_chernozemico}}) E atividade da argila
\eqn{\ge} \code{min_ta} (default 20 cmolc/kg argila) na maior parte
dos primeiros 100 cm do B (inclusive BA). Discrimina os Subgrupos
chernossolicos de Argissolos (Cap 5: PV, PVA).
}
\references{
Embrapa (2018), SiBCS 5a ed., Cap 5, p 134; Cap 7
            (Chernossolos).
}
