% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-spodosols-usda.R
\name{albic_horizon_usda}
\alias{albic_horizon_usda}
\title{Albic horizon (USDA, KST 13ed Ch 3)}
\usage{
albic_horizon_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Pass when an albic horizon (light-colored, eluvial; chroma <= 2,
value >= 4) >= 1 cm thick is present. Delegates to WRB albic
diagnostic.
}
