% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/report-pdf.R
\name{.escape_latex}
\alias{.escape_latex}
\title{Internal helper: .escape_latex}
\usage{
.escape_latex(x)
}
\description{
Internal helper: .escape_latex
}
\keyword{internal}
