% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-histosols-usda.R
\name{humilluvic_subgroup_usda}
\alias{humilluvic_subgroup_usda}
\title{Humilluvic Subgroup helper (Luvihemists)}
\usage{
humilluvic_subgroup_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Pass when a horizon >= 2 cm thick has humilluvic material (humus
translocated from above) >= 50\% volume. v0.8 deferred (no
specific column). Refinement to use a humilluvic_pct column or
a designation marker is planned.
}
