% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{test_mollic_structure}
\alias{test_mollic_structure}
\title{Mollic structure test (WRB 2022)}
\usage{
test_mollic_structure(h, candidate_layers = NULL)
}
\arguments{
\item{h}{Numeric threshold or option (see Details).}

\item{candidate_layers}{Numeric threshold or option (see Details).}
}
\description{
Excludes horizons that are simultaneously massive AND very hard when
dry. v0.1 implementation reads \code{structure_grade} and
\code{consistence_moist} as text and looks for the keyword pair.
}
