% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/soil-classes-at-location.R
\name{.wrb_to_sibcs_distribution}
\alias{.wrb_to_sibcs_distribution}
\title{Translate a WRB-RSG probability distribution to SiBCS-Ordem
probabilities via Schad (2023) Annex Table 1 / SiBCS 5ª ed. Annex A.
Many-to-many: a single WRB RSG may map to multiple SiBCS ordens
(we split the probability evenly).}
\usage{
.wrb_to_sibcs_distribution(dist)
}
\description{
Translate a WRB-RSG probability distribution to SiBCS-Ordem
probabilities via Schad (2023) Annex Table 1 / SiBCS 5ª ed. Annex A.
Many-to-many: a single WRB RSG may map to multiple SiBCS ordens
(we split the probability evenly).
}
\keyword{internal}
