% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/afsp.R
\name{.afsp_to_pedon}
\alias{.afsp_to_pedon}
\title{Build a soilKey PedonRecord from AfSP Profiles + Layers rows}
\usage{
.afsp_to_pedon(profile_row, layer_rows)
}
\description{
Build a soilKey PedonRecord from AfSP Profiles + Layers rows
}
\keyword{internal}
