% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{.subtest_result}
\alias{.subtest_result}
\title{Internal helper: .subtest_result}
\usage{
.subtest_result(
  passed,
  layers = integer(0),
  missing = character(0),
  details = NULL,
  notes = NA_character_
)
}
\description{
Internal helper: .subtest_result
}
\keyword{internal}
