% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0963.R
\name{qual_reductaquic}
\alias{qual_reductaquic}
\title{Reductaquic qualifier (ra): aquic + reductive at depth}
\usage{
qual_reductaquic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
WRB 2022 Ch 5 (Cryosols): "Saturation + reductimorphic features
(chroma <= 1, low value) at >= 50 cm depth."
}
