% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v091c.R
\name{qual_carbic}
\alias{qual_carbic}
\title{Carbic qualifier (cb): spodic horizon dominated by humus illuviation.
v0.9.1: spodic + OC >= 6\% in some spodic layer (the WRB threshold for
Carbic / "humus-Podzol" expression).}
\usage{
qual_carbic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Carbic qualifier (cb): spodic horizon dominated by humus illuviation.
v0.9.1: spodic + OC >= 6\% in some spodic layer (the WRB threshold for
Carbic / "humus-Podzol" expression).
}
