% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/redape.R
\name{.redape_canonical_label}
\alias{.redape_canonical_label}
\title{Normalise a Portuguese SiBCS label to a plural-canonical comparison key}
\usage{
.redape_canonical_label(s, pluralise = TRUE)
}
\description{
Normalise a Portuguese SiBCS label to a plural-canonical comparison key
}
\keyword{internal}
