% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0964.R
\name{qual_chloridic}
\alias{qual_chloridic}
\title{Chloridic supplementary qualifier (cl): high chloride
WRB 2022 Ch 5: "Containing >= 4 cmol(c)/kg chloride OR EC >= 8
dS/m within 100 cm." Proxy via electrical conductivity field
(\code{ec_ds_m}) when chloride is unavailable.}
\usage{
qual_chloridic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Chloridic supplementary qualifier (cl): high chloride
WRB 2022 Ch 5: "Containing >= 4 cmol(c)/kg chloride OR EC >= 8
dS/m within 100 cm." Proxy via electrical conductivity field
(\code{ec_ds_m}) when chloride is unavailable.
}
