% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-epipedons-usda.R
\name{folistic_epipedon_usda}
\alias{folistic_epipedon_usda}
\title{Folistic epipedon (USDA Soil Taxonomy, 13th edition)}
\usage{
folistic_epipedon_usda(pedon, min_oc_pct = 12, min_thickness_cm = 15)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_oc_pct}{Minimum OC for organic soil material (default 12).}

\item{min_thickness_cm}{Minimum thickness (default 15 cm).}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
A freely-drained surface organic horizon. Differs from the histic
epipedon in that it is saturated for less than 30 days per year.
Diagnostic for the Folists suborder of Histosols and the Folistels
great group of Histels.
}
\details{
KST 13ed required characteristics (Ch. 3, pp 13-14):
\itemize{
  \item Saturated < 30 days/year (and not artificially drained); AND
  \item Organic soil material: 15+ cm thick (with Sphagnum-rich
        exception 20-60 cm) OR Ap with OC >= 8 percent.
}
}
\references{
Soil Survey Staff (2022), KST 13ed, Ch. 3, pp 13-14.
}
