% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0963.R
\name{qual_murshic}
\alias{qual_murshic}
\title{Murshic qualifier (mr): partly drained organic with strong decomposition}
\usage{
qual_murshic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
WRB 2022 Ch 5 (Histosols): "Drained organic soils with sapric
decomposition (rubbed fibres < 17\%) and von Post >= 7 in upper 50
cm." Proxy via low rubbed fibre + von Post (when present).
}
