% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-gelisols-usda.R
\name{natric_horizon_usda}
\alias{natric_horizon_usda}
\title{Natric horizon helper (USDA, KST 13ed Ch 3)}
\usage{
natric_horizon_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Pass when natric_horizon (WRB natric: argillic + ESP > 15) is
present.
}
