% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/report-html.R
\name{.grade_class}
\alias{.grade_class}
\title{Grade -> CSS class}
\usage{
.grade_class(g)
}
\description{
Grade -> CSS class
}
\keyword{internal}
