% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0964.R
\name{qual_nudiargic}
\alias{qual_nudiargic}
\title{Nudiargic qualifier (nu): argic horizon at the surface}
\usage{
qual_nudiargic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
WRB 2022 Ch 5 (Acrisols / Lixisols / Alisols / Luvisols / Retisols):
"Argic horizon starting <= 5 cm from the soil surface (no
overlying eluvial / albic / mollic / umbric layer)."
}
