% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests-v033.R
\name{test_pattern_match}
\alias{test_pattern_match}
\title{Test that a character column matches a regex per layer}
\usage{
test_pattern_match(h, column, pattern, candidate_layers = NULL)
}
\arguments{
\item{h}{Horizons table.}

\item{column}{Character column name.}

\item{pattern}{Regex (case-insensitive).}

\item{candidate_layers}{Optional restriction.}
}
\value{
Sub-test result.
}
\description{
Test that a character column matches a regex per layer
}
\keyword{internal}
