% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-andisols-usda.R
\name{andisol_qualifying_usda}
\alias{andisol_qualifying_usda}
\title{Andisol Order qualifier (USDA, KST 13ed Ch 3, p 7)}
\usage{
andisol_qualifying_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Andisols have andic soil properties in 60\%+ of the thickness
between the surface and either:
\itemize{
  \item a depth of 60 cm; or
  \item a densic, lithic, or paralithic contact, a duripan, or
        a petrocalcic horizon (whichever is shallower).
}
v0.8.6 implementation: pass when total thickness of layers with
andic_soil_properties is >= 0.6 * (depth from surface to 60 cm).
}
\references{
Soil Survey Staff (2022), KST 13ed, Ch. 6, p 117.
}
