% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests.R
\name{ecec_per_clay}
\alias{ecec_per_clay}
\title{ECEC per kg clay (cmol_c)}
\usage{
ecec_per_clay(ecec_cmol, clay_pct)
}
\description{
ECEC per kg clay (cmol_c)
}
\keyword{internal}
