% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{make_empty_horizons}
\alias{make_empty_horizons}
\title{Build an empty horizons data.table with the canonical schema}
\usage{
make_empty_horizons(n = 0L)
}
\arguments{
\item{n}{Number of rows (default 0).}
}
\value{
A \code{data.table} with all canonical horizon columns filled
        with NAs of the correct type.
}
\description{
Build an empty horizons data.table with the canonical schema
}
\examples{
h <- make_empty_horizons(3)
nrow(h)
}
