% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/benchmark-unified.R
\name{.per_class_from_confusion}
\alias{.per_class_from_confusion}
\title{Per-class recall data.frame from a confusion matrix}
\usage{
.per_class_from_confusion(cm)
}
\description{
Per-class recall data.frame from a confusion matrix
}
\keyword{internal}
