% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-rsg-sibcs.R
\name{gleissolo}
\alias{gleissolo}
\title{Gleissolos (SiBCS Cap 4, p 112-113; conceito Cap 3, p 91-93)}
\usage{
gleissolo(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Horizonte glei iniciando \\<= 50 cm OR entre 50-150 cm imediatamente
subjacente a A/E ou H histico (com espessura insuficiente para
Organossolo), sem horizonte plintico/concrecionario/litoplintico
dentro de 200 cm.
}
