% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v091c.R
\name{qual_vetic}
\alias{qual_vetic}
\title{Vetic qualifier (vt): CEC (1 N NH4OAc, pH 7) by clay does not exceed
6 cmol+/kg clay in some layer at <= 100 cm. Stronger than the
ferralic-CEC threshold (<= 16 cmol+/kg clay).}
\usage{
qual_vetic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Vetic qualifier (vt): CEC (1 N NH4OAc, pH 7) by clay does not exceed
6 cmol+/kg clay in some layer at <= 100 cm. Stronger than the
ferralic-CEC threshold (<= 16 cmol+/kg clay).
}
