% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-atributos-sibcs.R
\name{carater_palico}
\alias{carater_palico}
\title{Carater palico (SiBCS Cap 11)}
\usage{
carater_palico(pedon, min_solum_cm = 80)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{min_solum_cm}{Default 80.}
}
\value{
\code{\link{DiagnosticResult}}.
}
\description{
Solos com espessura do solum (A + B, inclusive E e exclusive BC)
maior que \code{min_solum_cm} (default 80). Discrimina os Grandes
Grupos Palicos de Luvissolos (Cap 11 TCp, TXp) -- "desenvolvimento
excessivo" (do latim "pale").
}
\references{
Embrapa (2018), SiBCS 5a ed., Cap 11, p 214.
}
