% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-vertisols-usda.R
\name{calcic_subgroup_usda}
\alias{calcic_subgroup_usda}
\title{Calcic Subgroup helper -- delegates to calcic_horizon_usda within
\code{max_top_cm}.}
\usage{
calcic_subgroup_usda(pedon, max_top_cm = 100)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{max_top_cm}{Numeric threshold or option (see Details).}
}
\description{
Calcic Subgroup helper -- delegates to calcic_horizon_usda within
\code{max_top_cm}.
}
