% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-orders-usda.R
\name{gelisol_usda}
\alias{gelisol_usda}
\title{Gelisols (USDA Cap 9): gelic conditions / permafrost.}
\usage{
gelisol_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Order-level gate: cryic_conditions diagnostic from WRB delegated +
optional permafrost_temp_C if available.
}
