% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0933.R,
%   R/qualifiers-wrb2022-v0964.R
\name{qual_endocalcic}
\alias{qual_endocalcic}
\title{Endocalcic qualifier (cam): calcic horizon between 50 and 100 cm.}
\usage{
qual_endocalcic(pedon)

qual_endocalcic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
WRB 2022 Ch 5 (depth-conditional supplementary form of Calcic).
Referenced in Chernozems Ch 4. The diagnostic is the same as
Calcic; the difference is the depth band -- Endocalcic requires
the calcic horizon to start at >= 50 cm (deep, subsoil) rather
than within the upper 50 cm.
}
