% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-atributos-sibcs.R
\name{carater_gleissolico}
\alias{carater_gleissolico}
\title{Carater gleissolico (SiBCS Cap 5; horizonte_glei em posicao nao-Gleissolo)}
\usage{
carater_gleissolico(pedon, max_depth_cm = 150)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}

\item{max_depth_cm}{Profundidade maxima onde camadas qualificam
(default 150).}
}
\value{
\code{\link{DiagnosticResult}}.
}
\description{
Solos com horizonte glei (\code{\link{horizonte_glei}}) em posicao
nao diagnostica para Gleissolos (i.e., dentro de
\code{max_depth_cm} mas NAO satisfazendo os requisitos completos de
Gleissolo). Discrimina os Subgrupos gleissolicos de Argissolos
(Cap 5 PA), Cambissolos (Cap 6) e outros.
}
\references{
Embrapa (2018), SiBCS 5a ed., Cap 5, p 126; Cap 9
            (Gleissolos).
}
