% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/spectra-fetch-labels.R
\name{.wrb_to_sibcs_modal_ordem}
\alias{.wrb_to_sibcs_modal_ordem}
\title{Modal SiBCS Ordem for a WRB RSG (1:1 picked by Schad 2023).
Accepts either the singular ("Ferralsol") or plural ("Ferralsols")
form -- WoSIS, the WRB book, and OSSL all use slightly different
conventions.}
\usage{
.wrb_to_sibcs_modal_ordem(rsg)
}
\description{
Modal SiBCS Ordem for a WRB RSG (1:1 picked by Schad 2023).
Accepts either the singular ("Ferralsol") or plural ("Ferralsols")
form -- WoSIS, the WRB book, and OSSL all use slightly different
conventions.
}
\keyword{internal}
