% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-oxisols-usda.R
\name{sombric_subgroup_usda}
\alias{sombric_subgroup_usda}
\title{Sombric Subgroup helper (Oxisols Sombri-)
Pass when sombric horizon (humus illuviation in tropics) is
present. v0.8: detects via 'sombric' designation OR a B horizon
with V<=4 + V<=4 + chroma<=2 + OC>1 in 50-150 cm.}
\usage{
sombric_subgroup_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Sombric Subgroup helper (Oxisols Sombri-)
Pass when sombric horizon (humus illuviation in tropics) is
present. v0.8: detects via 'sombric' designation OR a B horizon
with V<=4 + V<=4 + chroma<=2 + OC>1 in 50-150 cm.
}
