% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics-andisols-usda.R
\name{andic_soil_properties_usda}
\alias{andic_soil_properties_usda}
\title{Andic soil properties (USDA, KST 13ed Ch 3, p 32)}
\usage{
andic_soil_properties_usda(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\value{
A \code{\link{DiagnosticResult}}.
}
\description{
Soil materials with one or both of the following:
\itemize{
  \item bulk_density <= 0.90 g/cm3 AND
        Al + 0.5*Fe (oxalate) >= 2.0\% AND
        phosphate_retention >= 85\%; OR
  \item Al + 0.5*Fe (oxalate) >= 0.4\% AND
        phosphate_retention >= 25\% AND
        volcanic_glass_pct varying with the texture-class proxy
        (deferred -- requires fine-earth fraction analysis).
}
}
\details{
Implementation (v0.8.6): primary "humic-andic" branch (bd <= 0.9 +
Al+0.5Fe >= 2 + Pret >= 85). The vitric-andic branch (lower Al+Fe
but high glass content) is partially captured.
}
\references{
Soil Survey Staff (2022), KST 13ed, Ch. 3, p 32.
}
