% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/spectra-neighbours.R
\name{.haversine_km}
\alias{.haversine_km}
\title{Great-circle distance (km) between (lat1, lon1) and the elementwise
(lat2, lon2) vectors.}
\usage{
.haversine_km(lat1, lon1, lat2, lon2)
}
\description{
Great-circle distance (km) between (lat1, lon1) and the elementwise
(lat2, lon2) vectors.
}
\keyword{internal}
