% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-diagnostic-tests-v04.R
\name{test_technic_hardmaterial_at_surface}
\alias{test_technic_hardmaterial_at_surface}
\title{Test for technic hard material covering the surface}
\usage{
test_technic_hardmaterial_at_surface(h, min_pct = 95, max_top_cm = 5)
}
\description{
WRB 2022 alternative for technic features: a layer at the surface
(top_cm <= \code{max_top_cm}, default 5) with
\code{technic_hardmaterial_pct >= min_pct} (default 95).
}
\keyword{internal}
