% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/qualifiers-wrb2022-v0963.R
\name{qual_cohesic}
\alias{qual_cohesic}
\title{Cohesic supplementary qualifier (co): cohesive horizon (extra-firm dry)
WRB 2022 Ch 5: "Containing layers with extreme dry consistence
AND moist consistence very firm." Implementation: matches via
\code{consistence_dry} ("extremely hard") OR
\code{consistence_moist} ("very firm"), within 100 cm.}
\usage{
qual_cohesic(pedon)
}
\arguments{
\item{pedon}{A \code{\link{PedonRecord}}.}
}
\description{
Cohesic supplementary qualifier (co): cohesive horizon (extra-firm dry)
WRB 2022 Ch 5: "Containing layers with extreme dry consistence
AND moist consistence very firm." Implementation: matches via
\code{consistence_dry} ("extremely hard") OR
\code{consistence_moist} ("very firm"), within 100 cm.
}
